######################################
## instalando os pacotes (se necessário)
######################################
#install.packages(c("maptools", "sp"), dep=T)
#####################################
## Carregando pacotes necessários
#####################################
require(maptools)     ## funções para importação/exportação e manipulação de mapas e dados geográficos    
gpclibPermit()        ## função para habilitar licença de uso
require(sp)           ## (classes) para representação de dados espaciais no R 
require(geoR)

par.ori <- par(no.readonly=TRUE)
##
## Bairros de Curitiba
##
## lendo dados tipo shapefile
ctba <- readShapePoly("bairros.shp", IDvar="CODE")

plot(ctba)

head(ctba@data)
ctba@data$NOME <- as.character(ctba@data$NOME)

## mudança de codificação de caracteres (só use se necessário, 
## depende do sistema operacional e do enconding do sistema)
## Veja os nomes dos unicípios e se os acentos aparecem corretamente
Encoding(ctba@data$NOME)
Encoding(ctba@data$NOME) <- "latin1"
ctba@data$NOME <- enc2native(ctba@data$NOME)
head(ctba@data)

## agora uma tabela de atributos "externa" (nao incluida no shapefile)
tb <- read.csv("tabe.csv", enc="latin1")
head(tb) ## ops nao importou corretamente assim!

## vamos importar de outra forma:
#tb <- read.csv2("tabe.csv", enc="latin1")
head(tb)
tb <- read.table("tabe.csv", sep=";", head=T, enc="latin1")

head(tb)
str(tb)

## e agora ordenando os dados corretamente, para compatibilizar a ordem
## dos minicípios no shape e na tabela de atributos
ind <- match(ctba@data$CODE, tb$CODE)
ind

tb <- tb[ind,]
row.names(tb) <- ctba$CODE

ctba <- spCbind(ctba, tb)

names(ctba)
head(ctba@data)

## montando as bordas de curitiba unindo os bairros
plot(unionSpatialPolygons(ctba, ID=rep(1, length(ctba)),
            avoidGEOS=T))

## os centroides sao obtidos com:
coordinates(ctba)

## verificando no grafico
plot(ctba)
points(coordinates(ctba))
## OK temos tudo que precismaos para montar o geodata!!
## vamos montar com o atributo segurança

ctbaGEO <- list(coords = coordinates(ctba),
                data = ctba@data[,"Segurança"],
                borders = unionSpatialPolygons(ctba, 
                            ID=rep(1, length(ctba)), 
                            avoidGEOS=T)@polygons[[1]]@Polygons[[1]]@coords
                            )
class(ctbaGEO) <- "geodata"
plot(ctbaGEO)

## Visualizando
require("RColorBrewer", "classInt")

par(mfrow=c(1,3), mar=c(2,2,0.5, 0.5))
INT <- classIntervals(ctba$Segurança, style="fixed", fixedBreaks=c(0, 20, 40, 60, 80, 100))
CORES.5 <- rev(c(rev(brewer.pal(3, "Blues")), brewer.pal(3, "Reds"))[-1])  ## tirando uma cor no final
COL <- findColours(INT, CORES.5)

plot(ctba, col=COL)
title("Segurança")

TB <- attr(COL, "table")
legtext <- paste(names(TB))  #, " (", TB, ")", sep="")
legend("bottomright", fill=attr(COL, "palette"), legend=legtext, bty="n")

## Visualizando um mapa do atributo: Segurança
INT <- classIntervals(ctba$Segurança, n=5, style="quantile")
CORES.5 <- rev(c(rev(brewer.pal(3, "Blues")), brewer.pal(3, "Reds"))[-1])  ## tirando uma cor no final
COL <- findColours(INT, CORES.5)

plot(ctba, col=COL)
title("Segurança")

TB <- attr(COL, "table")
legtext <- paste(names(TB))  #, " (", TB, ")", sep="")
legend("bottomright", fill=attr(COL, "palette"), legend=legtext, bty="n")

## Visualizando um mapa do atributo: Segurança
INT <- classIntervals(ctba$Segurança, n=5, style="sd")
CORES.5 <- rev(c(rev(brewer.pal(4, "Blues")), brewer.pal(3, "Reds")))  ## tirando uma cor no final
COL <- findColours(INT, CORES.5)

plot(ctba, col=COL)
title("Segurança")

TB <- attr(COL, "table")
legtext <- paste(names(TB))  #, " (", TB, ")", sep="")
legend("bottomright", fill=attr(COL, "palette"), legend=legtext, bty="n")



